cdist-type__rvm_gemset(7)
==========================

NAME
----
cdist-type__rvm_gemset - Manage gemsets through rvm


DESCRIPTION
-----------
RVM is the Ruby enVironment Manager for the Ruby programming language.


REQUIRED PARAMETERS
-------------------
user
    The remote user account to use
state
    Either "present" or "absent", defaults to "present".

BOOLEAN PARAMETERS
-------------------
default
    If present, set the given gemset as default.


EXAMPLES
--------

.. code-block:: sh

    # Install the gemset @myset for user charles on based on ruby-1.9.3-0
    __rvm_gemset ruby-1.9.3-p0@myset --user charles --state present

    # Do the same and make ruby-1.9.3-p0@myset the default gemset
    __rvm_gemset ruby-1.9.3-p0@myset --user charles --state present --default

    # Remove the gemset @myset for user john
    __rvm_ruby ruby-1.9.3-p0@myset --user john --state absent


SEE ALSO
--------
:strong:`cdist-type__rvm`\ (7), :strong:`cdist-type__rvm_gem`\ (7),
:strong:`cdist-type__rvm_ruby`\ (7)


AUTHORS
-------
Evax Software <contact@evax.fr>


COPYING
-------
Copyright \(C) 2012 Evax Software. Free use of this software is granted under
the terms of the GNU General Public License version 3 (GPLv3).
